==> release.12.2.28.1.tgz: cgi-cpn/dam/prontus_dam_regen_real.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO .
# -----------
# Actualiza todos los articulos de un publicador en base a su template
# El path al archivo de configuracion va en duro en el script.

# -------------------------------BEGIN SCRIPT--------------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ---------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);

    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use File::Copy;
use JSON;
use POSIX;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_dam;
use lib_logproc;
use lib_prontus;
use lib_setbd;
use lib_utils;
use lib_waitlock;
##/libs##

our ($TOT_REGS, $LOG_FILE, $PRONTUS_ID, $TOT_REGS_CON_ERR);

# ---------------------------------------------------------------
# MAIN.
# ---------------------------------------------------------------
main: {
    lib_utils::setUtf8();

    if ($ARGV[0]) {
        $PRONTUS_ID = $ARGV[0];
    } else {
        print "Error en parametros\n";
        exit;
    }
    print STDERR "------- comenzando el proceso -------\n";

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($PRONTUS_ID);
    if ($msg_load ne '') {
        print "Ha ocurrido un error: $msg_load\n";
        exit;
    }

    lib_utils::write_log('Actualiz. masiva', 'Articulo', '');
    $prontus_varglb::PRONTUS_ID = $PRONTUS_ID;
    # Establece log file
    $lib_logproc::LOG_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_dam_regen_log.html";

    print STDERR "Log File... $lib_logproc::LOG_FILE\n";

    # Init
    lib_logproc::flush_log();
    lib_logproc::writeRule();
    lib_logproc::add_to_log_count("INICIANDO PROCESO DE ACTUALIZACION DE MULTIMEDIA");

    # reparsea articulos en base a su tpl.
    &regenera_dam();

    lib_logproc::add_to_log_count("PROCESO DE ACTUALIZACION DE MULTIMEDIA FINALIZADO");
    lib_logproc::writeRule();

    $TOT_REGS = '0' if ($TOT_REGS eq '');
    $TOT_REGS_CON_ERR = '0' if ($TOT_REGS_CON_ERR eq '');

    lib_logproc::add_to_log("Nro. de registros procesados: $TOT_REGS\nRegistros con Errores: $TOT_REGS_CON_ERR");
    lib_logproc::add_to_log_finish("Operación finalizada.");

    &finishLoading('Regeneración de tablas de Multimedia terminada', $TOT_REGS);
    print STDERR "------- proceso terminado -------\n\n";
}

# ---------------------------------------------------------------
# SUB-RUTINAS.
# -------------

# Recorre todos los articulos via file system y repuebla la BD.
sub regenera_dam {
    # Inicia conexion a BD
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($base)) {
        &finishLoading("Error: $msg_err_bd\nProceso abortado.");
        lib_logproc::handle_error("Error: $msg_err_bd\nProceso abortado.");
    }

    # Antes de regenerar, borrar toda la tabla.
    my ($sql, $ret);
    if (&lib_setbd::existe_tabla($base,'ASSET') ) {
        # ASSET
        $sql = 'drop table ASSET';
        glib_dbi_03::ejecutar_sql($base, $sql);
        if ($base->errstr) {
            print STDERR "Error borrando tabla ASSET [$sql][$!][".$base->errstr."]\n";
            $ret = 0;
        } else {
            $ret = 1;
        }
    } else {
        $ret = 1;
    }

    if ($ret) {
        lib_logproc::add_to_log("- Tabla de Assets Eliminada");
        # Re-crear tabla ASSET
        my ($msg_ret, $hay_err) = &lib_setbd::crear_tabla_asset($base);
        lib_logproc::add_to_log($msg_ret);
        if ($hay_err) {
            &finishLoading("Error creando la estructura de la tabla de artículos, proceso abortado.");
            lib_logproc::handle_error("Error creando la estructura de la tabla de artículos, proceso abortado.");
        }

        my $ruta_dir = $prontus_varglb::DIR_SERVER
                       . $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'}
                       . $prontus_varglb::DIR_ARTIC;

        print STDERR "Leyendo XMLs... $ruta_dir\n";
        my @lisdir = glib_fildir_03::lee_dir($ruta_dir);

        @lisdir = grep !/^\./, @lisdir; # descarta directorios . y ..
        @lisdir = grep !/edic/, @lisdir; # descarta directorios edic

        @lisdir = sort {$a <=> $b} (@lisdir);

        # Para cada dirfecha procesa los articulos
        my $dircounter = 0;
        foreach my $dirfecha (@lisdir) {
            if (-d "$ruta_dir/$dirfecha/xml") {
                $dircounter++;
                &messageLoading('Vista: Default, Directorios Procesados: ' . $dircounter . '');
                lib_logproc::add_to_log_count("Procesando DIR [$dirfecha/xml]");
                print STDERR "  Procesando DIR [$dirfecha/xml]\n";
                &procesa_files("$ruta_dir/$dirfecha/xml", $dirfecha, $base);
            }
        }

        $base->disconnect;

    } else {
        &finishLoading('Error: No se pudo borrar la tabla de articulos por completo. Proceso abortado.');
        lib_logproc::handle_error('Error: No se pudo borrar la tabla de articulos por completo. Proceso abortado.');
    }
}

# ---------------------------------------------------------------
# Lee todos los articulos del directorio y los reparsea en base a su tpl.
sub procesa_files {
    my ($nom_campo, $val_campo, $dir_adjunto, $estilo);
    my ($ruta_dir_xml, $art_dirfecha, $base) = @_;

    my @lisfile = glib_fildir_03::lee_dir($ruta_dir_xml);
    @lisfile = grep !/^\./, @lisfile; # Elimina directorios . y ..
    my $count_files_in_dir = 0;
    my ($prontus_id, $dir_server) = ($prontus_varglb::PRONTUS_ID, $prontus_varglb::DIR_SERVER);
    foreach my $k_xml (@lisfile) {

        # Valida q el XML exista con largo <> 0 y que ademas su nombre corresponda a un timestamp valido.
        if ((-s "$ruta_dir_xml/$k_xml") && (! -d "$ruta_dir_xml/$k_xml") && ($k_xml =~ /^(\d{14})\.(xml)$/)) {
            $count_files_in_dir++;
            my $ts_artic = $1;
            lib_dam::procesa_artic($ts_artic,
                            $prontus_varglb::PRONTUS_ID,
                            $prontus_varglb::DIR_SERVER,
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PUBLIC_SERVER_NAME'},
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'CPAN_SERVER_NAME'},
                            $base,
                            1); # se esta regenerando por lo que no es necesario borrar los assets del articulo

            $TOT_REGS++;  # Total de articulos procesados, las iteraciones de multivista no se cuentan.
        };# if

    };# foreach
    lib_logproc::add_to_log("\t\t\t\t$count_files_in_dir archivos procesados en el DIR") if ($count_files_in_dir);
}

# ---------------------------------------------------------------
sub finishLoading {
    my ($msg, $total) = ($_[0], $_[1]);
    my $result_file = "$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_dam_regen.json";
    if($total) {
      $msg = '{"status":1, "msg":"'.$msg.'", "total": "'.$total.'"}';
    } else {
      $msg = '{"status":1, "msg":"'.$msg.'"}';
    }
    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$result_file", $msg);
}

# ---------------------------------------------------------------
sub messageLoading {
    my ($msg) = ($_[0]);
    my $result_file = "$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_dam_regen.json";
    if($msg) {
      $msg = '{"status":0, "inprogress":"'.$msg.'"}';
      glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$result_file", $msg);
    }
}

==> release.12.3.1.2.tgz: cgi-cpn/dam/prontus_dam_regen_real.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO .
# -----------
# Actualiza todos los articulos de un publicador en base a su template
# El path al archivo de configuracion va en duro en el script.

# -------------------------------BEGIN SCRIPT--------------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ---------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);

    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use File::Copy;
use JSON;
use POSIX;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_dam;
use lib_lang;
use lib_logproc;
use lib_prontus;
use lib_setbd;
use lib_utils;
use lib_waitlock;
##/libs##

our $TOT_REGS;

# ---------------------------------------------------------------
# MAIN.
# ---------------------------------------------------------------
main: {
    lib_utils::setUp();
    my $prontus_id;
    if ($ARGV[0]) {
        $prontus_id = $ARGV[0];
    } else {
        print lib_lang::get_message('global_use_instructions');
        print "perl $0 <prontus_id>\n";
        exit;
    }

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print "$msg_load\n";
        exit;
    }

    lib_utils::write_log('DAM Regen', lib_lang::get_message('artic_label'), '');
    # Establece log file
    $lib_logproc::LOG_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_dam_regen_log.html";
    $lib_logproc::JS_FILE  = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_dam_regen.json";

    print STDERR "Log File... $lib_logproc::LOG_FILE\n";

    # Init
    lib_logproc::writeRule();
    lib_logproc::add_to_log_count(lib_lang::get_message('dam_regen_start'));

    # lee los articulos y reconstruye bd de dam
    &regenera_dam();

    lib_logproc::add_to_log_count(lib_lang::get_message('dam_regen_end'));
    lib_logproc::writeRule();

    $TOT_REGS = '0' if ($TOT_REGS eq '');
    lib_logproc::add_to_log_finish(lib_lang::get_message('global_finalized'));

    lib_logproc::finishLoading(lib_lang::get_interpolated_message('dam_regen_complete', $TOT_REGS));
}

# SUB-RUTINAS.
# Recorre todos los articulos via file system y repuebla la BD.
sub regenera_dam {
    # Inicia conexion a BD
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($base)) {
        my $error = lib_lang::get_interpolated_message('global_regen_abort', $msg_err_bd);
        lib_logproc::finishLoading($error);
        lib_logproc::handle_error($error);
    }

    # Antes de regenerar, borrar toda la tabla.
    my ($sql, $ret);
    my $asset_table = lib_utils::get_table('asset');
    if (lib_setbd::existe_tabla($base, $asset_table) ) {
        # asset
        $sql = "drop table $asset_table";
        glib_dbi_03::ejecutar_sql($base, $sql);
        if ($base->errstr) {
            print STDERR "Error table delete asset [$sql][$!][".$base->errstr."]\n";
            $ret = 0;
        } else {
            $ret = 1;
        }
    } else {
        $ret = 1;
    }

    if ($ret) {
        lib_logproc::add_to_log(lib_lang::get_message('dam_regen_delete_asset'));
        # Re-crear tabla asset
        my ($msg_ret, $hay_err) = lib_setbd::crear_tabla_asset($base);
        lib_logproc::add_to_log(lib_lang::get_message($msg_ret));
        if ($hay_err) {
            my $error = lib_lang::get_interpolated_message('global_regen_abort', lib_lang::get_message($msg_ret));
            lib_logproc::finishLoading($error);
            lib_logproc::handle_error($error);
        }

        my $ruta_dir = $prontus_varglb::DIR_SERVER
                       . $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'}
                       . $prontus_varglb::DIR_ARTIC;

        my @lisdir = glib_fildir_03::lee_dir($ruta_dir);

        @lisdir = grep !/^\./, @lisdir; # descarta directorios . y ..
        @lisdir = grep !/edic/, @lisdir; # descarta directorios edic

        @lisdir = sort {$a <=> $b} (@lisdir);

        # Para cada dirfecha procesa los articulos
        my $dircounter = 0;
        foreach my $dirfecha (@lisdir) {
            next if (! -d "$ruta_dir/$dirfecha/xml");
            $dircounter++;
            lib_logproc::showProgress(lib_lang::get_interpolated_message('dam_regen_dir_counter', $dircounter));
            lib_logproc::add_to_log_count(lib_lang::get_interpolated_message('global_current_dir', "$dirfecha/xml"));
            print STDERR "    " , lib_lang::get_interpolated_message('global_current_dir', "$dirfecha/xml") , "\n";
            &procesa_files("$ruta_dir/$dirfecha/xml", $dirfecha, $base);
        }

        $base->disconnect;
    } else {
        my $error = lib_lang::get_message('dam_regen_error_delete_asset');
        lib_logproc::finishLoading($error);
        lib_logproc::handle_error($error);
    }
}

# ---------------------------------------------------------------
# Lee todos los articulos del directorio y los reparsea en base a su tpl.
sub procesa_files {
    my ($nom_campo, $val_campo, $dir_adjunto, $estilo);
    my ($ruta_dir_xml, $art_dirfecha, $base) = @_;

    my @lisfile = glib_fildir_03::lee_dir($ruta_dir_xml);
    @lisfile = grep !/^\./, @lisfile; # Elimina directorios . y ..
    my $count_files_in_dir = 0;
    my ($prontus_id, $dir_server) = ($prontus_varglb::PRONTUS_ID, $prontus_varglb::DIR_SERVER);
    foreach my $k_xml (@lisfile) {

        # Valida q el XML exista con largo <> 0 y que ademas su nombre corresponda a un timestamp valido.
        if ((-s "$ruta_dir_xml/$k_xml") && (! -d "$ruta_dir_xml/$k_xml") && ($k_xml =~ /^(\d{14})\.(xml)$/)) {
            $count_files_in_dir++;
            my $ts_artic = $1;
            lib_dam::procesa_artic($ts_artic,
                            $prontus_varglb::PRONTUS_ID,
                            $prontus_varglb::DIR_SERVER,
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PUBLIC_SERVER_NAME'},
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'CPAN_SERVER_NAME'},
                            $base,
                            1); # se esta regenerando por lo que no es necesario borrar los assets del articulo

            $TOT_REGS++;  # Total de articulos procesados, las iteraciones de multivista no se cuentan.
        }# if

    }# foreach

    lib_logproc::add_to_log("\t\t\t\t" . lib_lang::get_interpolated_message('global_regen_file_count', $count_files_in_dir)) if ($count_files_in_dir);
}
